@@ -18,6 +18,7 @@ class CuiApp:
     SHOW_MENU_MESSAGE = 'Type F1 or alt+/ for menu.'
     DEFAULT_THEME = 'basic'
     DEFAULT_PALETTE = 'dark'
+    NUM_NEWFILE = 1
 
     def __init__(self, config):
         self.config = config
@@ -276,10 +277,12 @@ class CuiApp:
 
                         if self.focus.editmode:
                             self.focus.editmode.on_keyevent(self.focus, c)
-                            self.focus.update_window()
+                            if self.focus:
+                                self.focus.update_window()
                 
                 if not inputs:
                     if self.mainframe.on_idle():
+                        self.set_idlejob()  # Reschedule idle procs
                         continue
 
                     # no input
