@@ -114,7 +114,7 @@ class Buffer(gappedbuf.GappedBuffer):
 
 class Document:
     all = weakref.WeakSet()  # should not be used!
-    provisional = False
+    temporary = False
     closed = False
     fileinfo = None
 
@@ -281,6 +281,12 @@ class Document:
         else:
             return (eol, self.buf[pos:eol])
 
+    def get_line_break(self, pos):
+        eol = self.buf.findchr('\n', pos, len(self.buf))
+        if eol == -1:
+            return len(self.buf)
+        return eol
+        
     def iterlines(self, pos):
         end = self.endpos()
         while pos < end:
