@@ -7,13 +7,14 @@ import kaa.log
 from kaa import document, encodingdef
 from kaa.filetype.default import defaultmode
 from kaa import consts
-
+from kaa import encodingdef
 
 class FileStorage:
 
     def adjust_encoding(self, encoding):
         if encoding.lower() == 'shiftjis':
             return 'cp932'
+        encoding = encodingdef.normalize_encname(encoding)
         return encoding
 
     def guess_japanese_encoding(self, filename):
@@ -103,11 +104,55 @@ class FileStorage:
         kaa.app.config.hist('dirname').add(dirname)
         kaa.app.last_dir = dirname
 
+    def newfile(self, mode=None, s='', temporary=False):
+        buf = document.Buffer()
+        if s:
+            buf.insert(0, s)
+
+        doc = document.Document(buf)
+        doc.temporary = temporary
+
+        doc.title = '<Untitled {}>'.format(kaa.app.NUM_NEWFILE)
+        kaa.app.NUM_NEWFILE += 1
+
+        doc.fileinfo = FileInfo()
+        if not mode:
+            mode = defaultmode.DefaultMode()
+        doc.setmode(mode)
+        return doc
+
     def openfile(self, filename, encoding=None, newline=None, nohist=False,
                  filemustexists=False):
         if not nohist:
             self._save_hist(filename)
-        return openfile(filename, encoding, newline, filemustexists)
+
+        fileinfo = self.get_fileinfo(filename, encoding, newline)
+        modecls = select_mode(fileinfo.fullpathname)
+        modecls.update_fileinfo(fileinfo)
+        
+        textio = self.get_textio(fileinfo, filemustexists)
+
+        buf = document.Buffer()
+        if textio:
+            src = textio.read()
+            if fileinfo.nlchars is not None:
+                src = src.replace(fileinfo.nlchars, '\n')
+            buf.insert(0, src)
+
+        doc = document.Document(buf)
+        doc.fileinfo = fileinfo
+
+        doc.setmode(modecls())
+
+        dir, file = os.path.split(fileinfo.fullpathname)
+        if not dir.endswith(os.path.sep):
+            dir += os.path.sep
+
+        kaa.app.messagebar.set_message('Read from {}({})'.format(file, dir))
+
+        kaa.app.config.hist_storage.flush()
+        return doc
+
 
     def save_document(self, doc, filename, encoding=None, newline=None,
                       nohist=False):
@@ -118,6 +163,7 @@ class FileStorage:
         if not doc.fileinfo:
             fileinfo = kaa.app.storage.get_fileinfo(
                 filename, encoding, newline)
+            doc.fileinfo = fileinfo
         else:
             if encoding is not None:
                 doc.fileinfo.encoding = encoding
@@ -131,6 +177,12 @@ class FileStorage:
             if doc.fileinfo.newline is None:
                 doc.fileinfo.newline = kaa.app.config.DEFAULT_NEWLINE
 
+        modecls = select_mode(filename)
+        if type(doc.mode) is not modecls:
+            doc.setmode(modecls())
+
+        doc.mode.update_fileinfo(doc.fileinfo, doc)
+
         with open(filename, 'w',
                   encoding=self.adjust_encoding(doc.fileinfo.encoding),
                   newline=consts.NEWLINE_CHARS[doc.fileinfo.newline],
@@ -145,21 +197,20 @@ class FileStorage:
         doc.mode.on_file_saved(fileinfo)
 
         doc.fileinfo = fileinfo
+        doc.fileinfo.check_update() # ensure timestamps updated
+
         doc.set_title(None)
-        doc.provisional = False
+        doc.temporary = False
         if doc.undo:
             doc.undo.saved()
 
-        mode = select_mode(filename)
-        if type(doc.mode) is not mode:
-            doc.setmode(mode())
-
-        dir, file = os.path.split(filename)
+        dir, file = os.path.split(fileinfo.fullpathname)
         if not dir.endswith(os.path.sep):
             dir += os.path.sep
 
         kaa.app.messagebar.set_message('Written to {}({})'.format(file, dir))
 
+        kaa.app.config.hist_storage.flush()
 
 class FileInfo:
     storage = None
@@ -205,56 +256,55 @@ class FileInfo:
 
 
 def select_mode(filename):
-    ext = os.path.splitext(filename)[1].lower()
-
     for pkg in kaa.app.config.get_mode_packages():
-        if ext in getattr(pkg, 'FILE_EXT', ()):
-            return pkg.get_modetype()
+        if hasattr(pkg, 'FileTypeInfo'):
+            ret = pkg.FileTypeInfo.select_mode(filename)
+            if ret:
+                return ret
 
     return defaultmode.DefaultMode
 
 
-def openfile(filename, encoding=None, newline=None, filemustexists=False):
-    # Open file
-    fileinfo = kaa.app.storage.get_fileinfo(filename, encoding, newline)
-    textio = kaa.app.storage.get_textio(fileinfo, filemustexists)
+#def openfile(filename, encoding=None, newline=None, filemustexists=False):
+#    # Open file
+#    fileinfo = kaa.app.storage.get_fileinfo(filename, encoding, newline)
+#    textio = kaa.app.storage.get_textio(fileinfo, filemustexists)
+#
+#    buf = document.Buffer()
+#    if textio:
+#        src = textio.read()
+#        if fileinfo.nlchars is not None:
+#            src = src.replace(fileinfo.nlchars, '\n')
+#        buf.insert(0, src)
+#
+#    doc = document.Document(buf)
+#    doc.fileinfo = fileinfo
+#    doc.setmode(select_mode(filename)())
+#
+#    dir, file = os.path.split(fileinfo.fullpathname)
+#    if not dir.endswith(os.path.sep):
+#        dir += os.path.sep
+#
+#    kaa.app.messagebar.set_message('Read from {}({})'.format(file, dir))
+#
+#    return doc
+#
 
-    buf = document.Buffer()
-    if textio:
-        src = textio.read()
-        if fileinfo.nlchars is not None:
-            src = src.replace(fileinfo.nlchars, '\n')
-        buf.insert(0, src)
-
-    doc = document.Document(buf)
-    doc.fileinfo = fileinfo
-    doc.setmode(select_mode(filename)())
-
-    dir, file = os.path.split(fileinfo.fullpathname)
-    if not dir.endswith(os.path.sep):
-        dir += os.path.sep
-
-    kaa.app.messagebar.set_message('Read from {}({})'.format(file, dir))
-
-    return doc
-
-NUM_NEWFILE = 1
-
-
-def newfile(mode=None, s='', provisional=False):
-    buf = document.Buffer()
-    if s:
-        buf.insert(0, s)
-
-    doc = document.Document(buf)
-    doc.provisional = provisional
-
-    global NUM_NEWFILE
-    doc.title = '<Untitled {}>'.format(NUM_NEWFILE)
-    NUM_NEWFILE += 1
-
-    doc.fileinfo = FileInfo()
-    if not mode:
-        mode = defaultmode.DefaultMode()
-    doc.setmode(mode)
-    return doc
+#
+#def newfile(mode=None, s='', provisional=False):
+#    buf = document.Buffer()
+#    if s:
+#        buf.insert(0, s)
+#
+#    doc = document.Document(buf)
+#    doc.provisional = provisional
+#
+#    global NUM_NEWFILE
+#    doc.title = '<Untitled {}>'.format(NUM_NEWFILE)
+#    NUM_NEWFILE += 1
+#
+#    doc.fileinfo = FileInfo()
+#    if not mode:
+#        mode = defaultmode.DefaultMode()
+#    doc.setmode(mode)
+#    return doc
