@@ -295,10 +295,10 @@ class GrepDlgMode(dialogmode.DialogMode):
     def _set_option_style(self, mark, style,
                           shortcutmark, shortcutstyle):
         f, t = self.document.marks[mark]
-        self.document.styles.setints(f, t, self.get_styleid(style))
+        self.document.setstyles(f, t, self.get_styleid(style))
 
         f = self.document.marks[shortcutmark]
-        self.document.styles.setints(f, f + 1, self.get_styleid(shortcutstyle))
+        self.document.setstyles(f, f + 1, self.get_styleid(shortcutstyle))
 
     def _get_optionstylename(self, f):
         if f:
@@ -420,7 +420,7 @@ class GrepDlgMode(dialogmode.DialogMode):
 
     def set_dir(self, wnd, dir):
         f, t = self.document.marks['directory']
-        self.edit_commands.replace_string(
+        self.replace_string(
             wnd, f, t, dir, update_cursor=True)
 
     def get_files(self):
