@@ -1,3 +1,4 @@
+import os
 import subprocess
 import collections
 import socket
@@ -120,6 +121,7 @@ class BreakPoint:
         self.lineno = lineno
 
 
+# todo: Define BreakPoints class
 breakpoints = []
 
 
@@ -138,7 +140,6 @@ def update_breakpoints():
         if hasattr(doc.mode, 'update_python_breakpoints'):
             doc.mode.update_python_breakpoints()
 
-
 class Debugger:
     port = None
     session = None
@@ -240,6 +241,9 @@ class Debugger:
         return b''.join(L)
 
     def show_callstack(self):
+        # update current breakpoints
+        update_breakpoints()
+
         if not self.debugpage or self.debugpage.closed:
             from kaa.ui.pythondebug import pythondebugmode
             wnd = pythondebugmode.show_callstack(self, self.current_frames)
@@ -286,7 +290,9 @@ class Debugger:
         elif type == 'pid':
             self.kaadbg_pid = value
         elif type == 'frame':
-            self.current_frames = value
+            event = value['event']
+            frame = value['frame']
+            self.current_frames = frame
             self.show_callstack()
         elif type == 'expr':
             self.show_expr_result(value)
@@ -360,6 +366,15 @@ ret.append(True)
     def get_breakpoints(self):
         return breakpoints
 
+    def del_breakpoint(self, d):
+        global breakpoints
+        breakpoints = [bp for bp in breakpoints if bp is not d]
+
+    def display_breakpoints(self):
+        for doc in document.Document.all:
+            if hasattr(doc.mode, 'display_breakpoint'):
+                doc.mode.display_breakpoint()
+
     def show_expr(self, depth, expr):
         command = '''
 import io, traceback
@@ -414,14 +429,22 @@ class ChildDebugger(Debugger):
         self.close()
 
     def run(self, s):
-        env = {
-            'KAADBG_DOMAINPORT': str(self.child.fileno())
-        }
+        env = os.environ.copy()
+        env['KAADBG_DOMAINPORT'] = str(self.child.fileno())
+
         self.set_running(True)
         self.process = subprocess.Popen(s, shell=True,
-                    pass_fds=(self.child.fileno(),),
-                    env=env)
+                            stdin=subprocess.PIPE,
+                            stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+                            bufsize=1,universal_newlines=True,
+                            pass_fds=(self.child.fileno(),),
+                            env=env)
         self.child.close()
+
+        self.process.stdin.close()
+        self.process.stdout.close()
+        self.process.stderr.close()
+
         kaa.app.messagebar.set_message("Process started.")
 
     def close(self):
