@@ -122,7 +122,9 @@ class WordCompleteInputMode(filterlist.FilterListInputDlgMode):
         words = [w for w in self.target.document.mode.get_word_list()
                  if w != curword]
 
-        words.extend(kaa.app.clipboard.get_all())
+        cb = kaa.app.clipboard.get()
+        if cb:
+            words.append(cb)
 
         list.document.mode.set_candidates(words)
         list.document.mode.candidates.sort(key=lambda v: v.text.upper())
